@@ -21,11 +21,11 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import ros_cdk_core
+import ros_cdk_core as _ros_cdk_core_7adfd82f
 
 
 class Certificate(
-    ros_cdk_core.Resource,
+    _ros_cdk_core_7adfd82f.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-cas.Certificate",
 ):
@@ -33,9 +33,9 @@ class Certificate(
 
     def __init__(
         self,
-        scope: ros_cdk_core.Construct,
+        scope: _ros_cdk_core_7adfd82f.Construct,
         id: builtins.str,
-        props: typing.Union["CertificateProps", typing.Dict[str, typing.Any]],
+        props: typing.Union["CertificateProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::CAS::Certificate``.
@@ -50,14 +50,7 @@ class Certificate(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            def stub(
-                scope: ros_cdk_core.Construct,
-                id: builtins.str,
-                props: typing.Union[CertificateProps, typing.Dict[str, typing.Any]],
-                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b234d46789e8c2016fcf32b39f570e7d2a9ab6c0bd7e26c709d41b68738956a3)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -66,9 +59,9 @@ class Certificate(
 
     @builtins.property
     @jsii.member(jsii_name="attrCertId")
-    def attr_cert_id(self) -> ros_cdk_core.IResolvable:
+    def attr_cert_id(self) -> _ros_cdk_core_7adfd82f.IResolvable:
         '''Attribute CertId: Certificate ID.'''
-        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrCertId"))
+        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrCertId"))
 
 
 @jsii.data_type(
@@ -86,11 +79,11 @@ class CertificateProps:
     def __init__(
         self,
         *,
-        cert: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-        key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-        name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-        lang: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-        source_ip: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        cert: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+        key: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+        name: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+        lang: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+        source_ip: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::CAS::Certificate``.
 
@@ -101,22 +94,13 @@ class CertificateProps:
         :param source_ip: Property sourceIp: Specifies the source IP address of the request.
         '''
         if __debug__:
-            def stub(
-                *,
-                cert: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-                key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-                lang: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-                source_ip: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__07e0a2ae254f018b4c89dd3f7f79bcc2272bc543adacd01e9c591a9f9e589493)
             check_type(argname="argument cert", value=cert, expected_type=type_hints["cert"])
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument lang", value=lang, expected_type=type_hints["lang"])
             check_type(argname="argument source_ip", value=source_ip, expected_type=type_hints["source_ip"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "cert": cert,
             "key": key,
             "name": name,
@@ -127,50 +111,50 @@ class CertificateProps:
             self._values["source_ip"] = source_ip
 
     @builtins.property
-    def cert(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def cert(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Property cert: Specify the content of the certificate.
 
         To use the PEM encoding format.
         '''
         result = self._values.get("cert")
         assert result is not None, "Required property 'cert' is missing"
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], result)
 
     @builtins.property
-    def key(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def key(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Property key: Specify the certificate private key content.
 
         To use the PEM encoding format.
         '''
         result = self._values.get("key")
         assert result is not None, "Required property 'key' is missing"
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], result)
 
     @builtins.property
-    def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def name(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Property name: Custom certificate name.
 
         The certificate name under a user cannot be duplicated.
         '''
         result = self._values.get("name")
         assert result is not None, "Required property 'name' is missing"
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], result)
 
     @builtins.property
     def lang(
         self,
-    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
         '''Property lang: Specifies the language type for requesting and receiving messages.'''
         result = self._values.get("lang")
-        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
 
     @builtins.property
     def source_ip(
         self,
-    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
         '''Property sourceIp: Specifies the source IP address of the request.'''
         result = self._values.get("source_ip")
-        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -185,7 +169,7 @@ class CertificateProps:
 
 
 class RosCertificate(
-    ros_cdk_core.RosResource,
+    _ros_cdk_core_7adfd82f.RosResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-cas.RosCertificate",
 ):
@@ -193,9 +177,9 @@ class RosCertificate(
 
     def __init__(
         self,
-        scope: ros_cdk_core.Construct,
+        scope: _ros_cdk_core_7adfd82f.Construct,
         id: builtins.str,
-        props: typing.Union["RosCertificateProps", typing.Dict[str, typing.Any]],
+        props: typing.Union["RosCertificateProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::CAS::Certificate``.
@@ -206,14 +190,7 @@ class RosCertificate(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            def stub(
-                scope: ros_cdk_core.Construct,
-                id: builtins.str,
-                props: typing.Union[RosCertificateProps, typing.Dict[str, typing.Any]],
-                enable_resource_property_constraint: builtins.bool,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8810f552d9ea1a7b2e94b1f7b6e7382fee697cf796c7ca9dd1b936f486b6dcbc)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -229,9 +206,7 @@ class RosCertificate(
         :param props: -
         '''
         if __debug__:
-            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__536b746d585cb4253afbf99ba729eea3b43a4cfe97ab1df64168beda75a14a53)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -243,11 +218,11 @@ class RosCertificate(
 
     @builtins.property
     @jsii.member(jsii_name="attrCertId")
-    def attr_cert_id(self) -> ros_cdk_core.IResolvable:
+    def attr_cert_id(self) -> _ros_cdk_core_7adfd82f.IResolvable:
         '''
         :Attribute: CertId: Certificate ID.
         '''
-        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrCertId"))
+        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrCertId"))
 
     @builtins.property
     @jsii.member(jsii_name="rosProperties")
@@ -256,20 +231,19 @@ class RosCertificate(
 
     @builtins.property
     @jsii.member(jsii_name="cert")
-    def cert(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def cert(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''
         :Property: cert: Specify the content of the certificate. To use the PEM encoding format.
         '''
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], jsii.get(self, "cert"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "cert"))
 
     @cert.setter
-    def cert(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+    def cert(
+        self,
+        value: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f2354cf030ed10aa7c0accbe6ddec0c6e653f40430c22226c0f125318742b45b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cert", value)
 
@@ -281,47 +255,43 @@ class RosCertificate(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            def stub(value: builtins.bool) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__71db2b31a9e51fe92b0cb684a0fb906fd653cbc00ccb08c09eb445a2a4b767a4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
     @builtins.property
     @jsii.member(jsii_name="key")
-    def key(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def key(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''
         :Property: key: Specify the certificate private key content. To use the PEM encoding format.
         '''
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], jsii.get(self, "key"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "key"))
 
     @key.setter
-    def key(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+    def key(
+        self,
+        value: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d90d80db51c7504011d35ce24be1b5c0fed275078cf00686bcf3005c94217c59)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "key", value)
 
     @builtins.property
     @jsii.member(jsii_name="name")
-    def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def name(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''
         :Property: name: Custom certificate name. The certificate name under a user cannot be duplicated.
         '''
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], jsii.get(self, "name"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "name"))
 
     @name.setter
-    def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+    def name(
+        self,
+        value: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__84c67126c949c0a38caf260021375fbb5ea65427af261cb29eafdcb2a182c9af)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -329,23 +299,19 @@ class RosCertificate(
     @jsii.member(jsii_name="lang")
     def lang(
         self,
-    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
         '''
         :Property: lang: Specifies the language type for requesting and receiving messages.
         '''
-        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "lang"))
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], jsii.get(self, "lang"))
 
     @lang.setter
     def lang(
         self,
-        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+        value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2b80787f6c95cde7755ed275da224e1264dfb3f62abe3b73e984f1d9f240ba2f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "lang", value)
 
@@ -353,23 +319,19 @@ class RosCertificate(
     @jsii.member(jsii_name="sourceIp")
     def source_ip(
         self,
-    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
         '''
         :Property: sourceIp: Specifies the source IP address of the request.
         '''
-        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "sourceIp"))
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], jsii.get(self, "sourceIp"))
 
     @source_ip.setter
     def source_ip(
         self,
-        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+        value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__67a982d45319e32cd72f9f23c0ced9265141968b5f935eb4ac8e8a97e1f46cf6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceIp", value)
 
@@ -389,11 +351,11 @@ class RosCertificateProps:
     def __init__(
         self,
         *,
-        cert: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-        key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-        name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-        lang: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-        source_ip: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        cert: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+        key: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+        name: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+        lang: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+        source_ip: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::CAS::Certificate``.
 
@@ -404,22 +366,13 @@ class RosCertificateProps:
         :param source_ip: 
         '''
         if __debug__:
-            def stub(
-                *,
-                cert: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-                key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-                lang: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-                source_ip: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5ff148f63432986b50f253a72db70c1105e107f3da35b2b6ff541dfd30de675e)
             check_type(argname="argument cert", value=cert, expected_type=type_hints["cert"])
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument lang", value=lang, expected_type=type_hints["lang"])
             check_type(argname="argument source_ip", value=source_ip, expected_type=type_hints["source_ip"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "cert": cert,
             "key": key,
             "name": name,
@@ -430,51 +383,51 @@ class RosCertificateProps:
             self._values["source_ip"] = source_ip
 
     @builtins.property
-    def cert(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def cert(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''
         :Property: cert: Specify the content of the certificate. To use the PEM encoding format.
         '''
         result = self._values.get("cert")
         assert result is not None, "Required property 'cert' is missing"
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], result)
 
     @builtins.property
-    def key(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def key(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''
         :Property: key: Specify the certificate private key content. To use the PEM encoding format.
         '''
         result = self._values.get("key")
         assert result is not None, "Required property 'key' is missing"
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], result)
 
     @builtins.property
-    def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+    def name(self) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''
         :Property: name: Custom certificate name. The certificate name under a user cannot be duplicated.
         '''
         result = self._values.get("name")
         assert result is not None, "Required property 'name' is missing"
-        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], result)
 
     @builtins.property
     def lang(
         self,
-    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
         '''
         :Property: lang: Specifies the language type for requesting and receiving messages.
         '''
         result = self._values.get("lang")
-        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
 
     @builtins.property
     def source_ip(
         self,
-    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
         '''
         :Property: sourceIp: Specifies the source IP address of the request.
         '''
         result = self._values.get("source_ip")
-        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -496,3 +449,85 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__b234d46789e8c2016fcf32b39f570e7d2a9ab6c0bd7e26c709d41b68738956a3(
+    scope: _ros_cdk_core_7adfd82f.Construct,
+    id: builtins.str,
+    props: typing.Union[CertificateProps, typing.Dict[builtins.str, typing.Any]],
+    enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__07e0a2ae254f018b4c89dd3f7f79bcc2272bc543adacd01e9c591a9f9e589493(
+    *,
+    cert: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    key: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    name: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    lang: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+    source_ip: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8810f552d9ea1a7b2e94b1f7b6e7382fee697cf796c7ca9dd1b936f486b6dcbc(
+    scope: _ros_cdk_core_7adfd82f.Construct,
+    id: builtins.str,
+    props: typing.Union[RosCertificateProps, typing.Dict[builtins.str, typing.Any]],
+    enable_resource_property_constraint: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__536b746d585cb4253afbf99ba729eea3b43a4cfe97ab1df64168beda75a14a53(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f2354cf030ed10aa7c0accbe6ddec0c6e653f40430c22226c0f125318742b45b(
+    value: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__71db2b31a9e51fe92b0cb684a0fb906fd653cbc00ccb08c09eb445a2a4b767a4(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d90d80db51c7504011d35ce24be1b5c0fed275078cf00686bcf3005c94217c59(
+    value: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__84c67126c949c0a38caf260021375fbb5ea65427af261cb29eafdcb2a182c9af(
+    value: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2b80787f6c95cde7755ed275da224e1264dfb3f62abe3b73e984f1d9f240ba2f(
+    value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__67a982d45319e32cd72f9f23c0ced9265141968b5f935eb4ac8e8a97e1f46cf6(
+    value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5ff148f63432986b50f253a72db70c1105e107f3da35b2b6ff541dfd30de675e(
+    *,
+    cert: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    key: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    name: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
+    lang: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+    source_ip: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
